summaryrefslogtreecommitdiffstats
path: root/crawl-ref
diff options
context:
space:
mode:
authordshaligram <dshaligram@c06c8d41-db1a-0410-9941-cceddc491573>2007-06-20 07:06:33 +0000
committerdshaligram <dshaligram@c06c8d41-db1a-0410-9941-cceddc491573>2007-06-20 07:06:33 +0000
commitb31de410dd1c21ca6e63d823ecd2619b6bfa7299 (patch)
tree9010628a8524e3648350ba59d0902d6436f6948f /crawl-ref
parentefb6b63c27fab83612572f7ebba318f40886e1d7 (diff)
downloadcrawl-ref-b31de410dd1c21ca6e63d823ecd2619b6bfa7299.tar.gz
crawl-ref-b31de410dd1c21ca6e63d823ecd2619b6bfa7299.zip
Correct "artifact" to "artefact".
git-svn-id: https://crawl-ref.svn.sourceforge.net/svnroot/crawl-ref/trunk@1607 c06c8d41-db1a-0410-9941-cceddc491573
Diffstat (limited to 'crawl-ref')
-rw-r--r--crawl-ref/source/chardump.cc6
-rw-r--r--crawl-ref/source/clua.cc4
-rw-r--r--crawl-ref/source/command.cc2
-rw-r--r--crawl-ref/source/describe.cc12
-rw-r--r--crawl-ref/source/describe.h2
-rw-r--r--crawl-ref/source/enum.h2
-rw-r--r--crawl-ref/source/initfile.cc7
-rw-r--r--crawl-ref/source/item_use.cc2
-rw-r--r--crawl-ref/source/makeitem.cc2
-rw-r--r--crawl-ref/source/randart.cc2
-rw-r--r--crawl-ref/source/randart.h2
-rw-r--r--crawl-ref/source/spells4.cc8
-rw-r--r--crawl-ref/source/stash.cc6
-rw-r--r--crawl-ref/source/unrand.h4
14 files changed, 32 insertions, 29 deletions
diff --git a/crawl-ref/source/clua.cc b/crawl-ref/source/clua.cc
index 24bf44f188..9140cf5d2b 100644
--- a/crawl-ref/source/clua.cc
+++ b/crawl-ref/source/clua.cc
@@ -1340,7 +1340,7 @@ static int l_item_weap_skill(lua_State *ls)
return (2);
}
-static int l_item_artifact(lua_State *ls)
+static int l_item_artefact(lua_State *ls)
{
LUA_ITEM(item, 1);
if (!item || !is_valid_item(*item))
@@ -1378,7 +1378,7 @@ static int l_item_branded(lua_State *ls)
static const struct luaL_reg item_lib[] =
{
- { "artifact", l_item_artifact },
+ { "artefact", l_item_artefact },
{ "branded", l_item_branded },
{ "class", l_item_class },
{ "subtype", l_item_subtype },
diff --git a/crawl-ref/source/command.cc b/crawl-ref/source/command.cc
index 2ed5176f77..53a2493c56 100644
--- a/crawl-ref/source/command.cc
+++ b/crawl-ref/source/command.cc
@@ -921,7 +921,7 @@ void list_commands(bool wizard, int hotkey)
"\n"
"Searching in stashes allows regular\n"
"expressions, and terms like 'altar'\n"
- "or 'artifact' or 'long blades'.\n",
+ "or 'artefact' or 'long blades'.\n",
true, true, cmdhelp_textfilter);
cols.add_formatted(
diff --git a/crawl-ref/source/describe.cc b/crawl-ref/source/describe.cc
index 882e19c74c..eb834501cd 100644
--- a/crawl-ref/source/describe.cc
+++ b/crawl-ref/source/describe.cc
@@ -10,7 +10,7 @@
* <4> 10/14/99 BCR enummed describe_god()
* <3> 10/13/99 BCR Added GOD_NO_GOD case in describe_god()
* <2> 5/20/99 BWR Replaced is_artifact with
- * is_dumpable_artifact
+ * is_dumpable_artefact
* <1> 4/20/99 JDJ Reformatted, uses string objects,
* split out 10 new functions from
* describe_item(), added
@@ -3113,7 +3113,7 @@ static std::string describe_misc_item( const item_def &item )
// Public Functions
// ========================================================================
-bool is_dumpable_artifact( const item_def &item, bool verbose)
+bool is_dumpable_artefact( const item_def &item, bool verbose)
{
bool ret = false;
@@ -3135,7 +3135,7 @@ bool is_dumpable_artifact( const item_def &item, bool verbose)
}
return (ret);
-} // end is_dumpable_artifact()
+}
//---------------------------------------------------------------
@@ -3261,13 +3261,13 @@ std::string get_item_description( const item_def &item, bool verbose,
<< "." << (mass % 10)
<< " aum. "; // arbitrary unit of mass
- if ( is_dumpable_artifact(item, false) )
+ if ( is_dumpable_artefact(item, false) )
{
if (item.base_type == OBJ_ARMOUR || item.base_type == OBJ_WEAPONS)
- description << "$$This ancient artifact cannot be changed "
+ description << "$$This ancient artefact cannot be changed "
"by magic or mundane means.";
else
- description << "$$It is an ancient artifact.";
+ description << "$$It is an ancient artefact.";
}
}
diff --git a/crawl-ref/source/describe.h b/crawl-ref/source/describe.h
index 9c032f8e7e..efef39a872 100644
--- a/crawl-ref/source/describe.h
+++ b/crawl-ref/source/describe.h
@@ -23,7 +23,7 @@
/* ***********************************************************************
* called from: chardump - spells4
* *********************************************************************** */
-bool is_dumpable_artifact( const item_def &item, bool verbose );
+bool is_dumpable_artefact( const item_def &item, bool verbose );
// last updated 12may2000 {dlb}
/* ***********************************************************************
diff --git a/crawl-ref/source/initfile.cc b/crawl-ref/source/initfile.cc
index 717446b8e0..6fb3700514 100644
--- a/crawl-ref/source/initfile.cc
+++ b/crawl-ref/source/initfile.cc
@@ -693,7 +693,7 @@ void game_options::reset_options()
dump_kill_places = KDO_ONE_PLACE;
dump_message_count = 7;
- dump_item_origins = IODS_ARTIFACTS | IODS_RODS;
+ dump_item_origins = IODS_ARTEFACTS | IODS_RODS;
dump_item_origin_price = -1;
drop_mode = DM_MULTI;
@@ -2377,8 +2377,9 @@ void game_options::read_option_line(const std::string &str, bool runscript)
for (int i = 0, count = choices.size(); i < count; ++i)
{
const std::string &ch = choices[i];
- if (ch == "artifacts")
- dump_item_origins |= IODS_ARTIFACTS;
+ if (ch == "artefacts" || ch == "artifacts"
+ || ch == "artefact" || ch == "artifact")
+ dump_item_origins |= IODS_ARTEFACTS;
else if (ch == "ego_arm" || ch == "ego armour"
|| ch == "ego_armour")
dump_item_origins |= IODS_EGO_ARMOUR;
diff --git a/crawl-ref/source/item_use.cc b/crawl-ref/source/item_use.cc
index c89044ce54..271852cd2d 100644
--- a/crawl-ref/source/item_use.cc
+++ b/crawl-ref/source/item_use.cc
@@ -3637,7 +3637,7 @@ void use_randart(const item_def &item)
if (!alreadyknown && dangerous)
{
- // Xom loves it when you use an unknown random artifact and
+ // Xom loves it when you use an unknown random artefact and
// there is a dangerous monster nearby...
xom_is_stimulated(256);
}
diff --git a/crawl-ref/source/makeitem.cc b/crawl-ref/source/makeitem.cc
index 81bdcd6b86..8165e0a4ed 100644
--- a/crawl-ref/source/makeitem.cc
+++ b/crawl-ref/source/makeitem.cc
@@ -1033,7 +1033,7 @@ int items( int allow_uniques, // not just true-false,
&& random2(3000) <= 30 + (item_level * 3) && one_chance_in(12))
{
#ifdef DEBUG_DIAGNOSTICS
- mprf(MSGCH_DIAGNOSTICS, "Making fixed artifact.");
+ mprf(MSGCH_DIAGNOSTICS, "Making fixed artefact.");
#endif
if (make_item_fixed_artefact( mitm[p], (item_level == 51) ))
{
diff --git a/crawl-ref/source/randart.cc b/crawl-ref/source/randart.cc
index bb0588a83a..0682a26c0e 100644
--- a/crawl-ref/source/randart.cc
+++ b/crawl-ref/source/randart.cc
@@ -1,6 +1,6 @@
/*
* File: randart.cc
- * Summary: Random and unrandom artifact functions.
+ * Summary: Random and unrandom artefact functions.
* Written by: Linley Henzell
*
* Modified for Crawl Reference by $Author$ on $Date$
diff --git a/crawl-ref/source/randart.h b/crawl-ref/source/randart.h
index fe36bffecc..fc8f3905d7 100644
--- a/crawl-ref/source/randart.h
+++ b/crawl-ref/source/randart.h
@@ -1,6 +1,6 @@
/*
* File: randart.cc
- * Summary: Random and unrandom artifact functions.
+ * Summary: Random and unrandom artefact functions.
* Written by: Linley Henzell
*
* Change History (most recent first):
diff --git a/crawl-ref/source/spells4.cc b/crawl-ref/source/spells4.cc
index 986ab3d180..fa521f1d35 100644
--- a/crawl-ref/source/spells4.cc
+++ b/crawl-ref/source/spells4.cc
@@ -530,9 +530,11 @@ static void cast_detect_magic(int pow)
while (item != NON_ITEM)
{
next = mitm[item].link;
- if (is_dumpable_artifact
- (mitm[item].base_type, mitm[item].sub_type, mitm[item].plus,
- mitm[item].plus2, mitm[item].special, 0, 0))
+ if (is_dumpable_artefact(mitm[item].base_type,
+ mitm[item].sub_type,
+ mitm[item].plus,
+ mitm[item].plus2,
+ mitm[item].special, 0, 0))
{
strong++;
//FIXME: do checks for randart properties
diff --git a/crawl-ref/source/stash.cc b/crawl-ref/source/stash.cc
index 5b12514b84..a1ed94ed47 100644
--- a/crawl-ref/source/stash.cc
+++ b/crawl-ref/source/stash.cc
@@ -518,7 +518,7 @@ bool Stash::matches_search(const std::string &prefix,
continue;
}
- if (is_dumpable_artifact(item, false))
+ if (is_dumpable_artefact(item, false))
{
std::string desc =
munge_description(get_item_description(item, false, true));
@@ -590,7 +590,7 @@ void Stash::write(std::ostream &os,
<< (!verified && (items.size() > 1 || i)? " (still there?)" : "")
<< std::endl;
- if (is_dumpable_artifact(item, false))
+ if (is_dumpable_artefact(item, false))
{
std::string desc =
munge_description(get_item_description(item, false, true));
@@ -723,7 +723,7 @@ std::string ShopInfo::shop_item_desc(const shop_item &si) const
if (shoptype_identifies_stock(this->shoptype))
const_cast<shop_item&>(si).item.flags |= ISFLAG_IDENT_MASK;
- if (is_dumpable_artifact(si.item, false))
+ if (is_dumpable_artefact(si.item, false))
{
desc = munge_description(get_item_description(si.item, false, true));
trim_string(desc);
diff --git a/crawl-ref/source/unrand.h b/crawl-ref/source/unrand.h
index 4548652883..64e7061296 100644
--- a/crawl-ref/source/unrand.h
+++ b/crawl-ref/source/unrand.h
@@ -1,6 +1,6 @@
/*
* File: unrand.cc
- * Summary: Definitions for unrandom artifacts.
+ * Summary: Definitions for unrandom artefacts.
* Written by: Linley Henzell
*
* Modified for Crawl Reference by $Author$ on $Date$
@@ -865,7 +865,7 @@
0, -30 // stealth
}
,
- "It's a really dark and malign artifact and no wise man would even touch it.",
+ "It's a really dark and malign artefact and no wise man would even touch it.",
"",
""
}
diff --git a/crawl-ref/source/chardump.cc b/crawl-ref/source/chardump.cc
index 5c71ab2214..f7d655323a 100644
--- a/crawl-ref/source/chardump.cc
+++ b/crawl-ref/source/chardump.cc
@@ -12,7 +12,7 @@
* <3> 6/13/99 BWR Improved spell listing
* <2> 5/30/99 JDJ dump_spells dumps failure rates (from Brent).
* <1> 4/20/99 JDJ Reformatted, uses string objects, split out 7
* functions from dump_char, dumps artifact info.
*/
#include "AppHdr.h"
@@ -561,7 +561,7 @@ static bool dump_item_origin(const item_def &item, int value)
if (flags == IODS_EVERYTHING)
return (true);
- if (fs(IODS_ARTIFACTS)
+ if (fs(IODS_ARTEFACTS)
&& (is_random_artefact(item) || is_fixed_artefact(item))
&& item_ident(item, ISFLAG_KNOW_PROPERTIES))
return (true);
@@ -698,7 +698,7 @@ static void sdump_inventory(const std::string &, std::string & text)
text += "\n" " (" + origin_desc(you.inv[j]) + ")";
}
- if (is_dumpable_artifact( you.inv[j], false ))
+ if (is_dumpable_artefact( you.inv[j], false ))
{
text2 = get_item_description( you.inv[j],
false,
@@ -12,7 +12,7 @@
* <2> 5/30/99 JDJ dump_spells dumps failure rates (from Brent).
* <1> 4/20/99 JDJ Reformatted, uses string objects, split out 7
- * functions from dump_char, dumps artifact info.
+ * functions from dump_char, dumps artefact info.
*/
#include "AppHdr.h"
diff --git a/crawl-ref/source/enum.h b/crawl-ref/source/enum.h
index 0a507f8e79..a86a978218 100644
--- a/crawl-ref/source/enum.h
+++ b/crawl-ref/source/enum.h
@@ -1518,7 +1518,7 @@ enum item_make_species_type
enum item_origin_dump_selector
{
IODS_PRICE = 0, // Extra info is provided based on price
- IODS_ARTIFACTS = 1, // Extra information on artifacts
+ IODS_ARTEFACTS = 1, // Extra information on artefacts
IODS_EGO_ARMOUR = 2,
IODS_EGO_WEAPON = 4,
IODS_JEWELLERY = 8,